==> haskell-unbounded-delays-0.1.1.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unbounded-delays
version:              0.1.1.0
visibility:           public
id:                   unbounded-delays-0.1.1.0-4sj42R47NHJDAQ5TZPZvQZ
key:                  unbounded-delays-0.1.1.0-4sj42R47NHJDAQ5TZPZvQZ
license:              BSD-3-Clause
copyright:            2011-2012 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

homepage:             https://github.com/basvandijk/unbounded-delays
synopsis:             Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.

category:             Concurrency
abi:                  a2c93ad73584a4b87bdf9fb154043eb6
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout

import-dirs:          /usr/lib/ghc-8.8.3/site-local/unbounded-delays-0.1.1.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/unbounded-delays-0.1.1.0
hs-libraries:         HSunbounded-delays-0.1.1.0-4sj42R47NHJDAQ5TZPZvQZ
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock

haddock-html:         /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.1.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unbounded-delays
version:              0.1.1.0
visibility:           public
id:                   unbounded-delays-0.1.1.0-FtumT97vOHS4wkXodPiLmD
key:                  unbounded-delays-0.1.1.0-FtumT97vOHS4wkXodPiLmD
license:              BSD-3-Clause
copyright:            2011-2012 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

homepage:             https://github.com/basvandijk/unbounded-delays
synopsis:             Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.

category:             Concurrency
abi:                  c306eab4bc232661939393e8e2a4d1c7
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout

import-dirs:          /usr/lib/ghc-8.10.1/site-local/unbounded-delays-0.1.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/unbounded-delays-0.1.1.0
hs-libraries:         HSunbounded-delays-0.1.1.0-FtumT97vOHS4wkXodPiLmD
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock

haddock-html:         /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
